==> horde-3.1.4.tgz: horde/lib/Horde/NLS/carsigns.php <==
<?php
/**
 * The list of international license plate codes.
 *
 * $Horde: framework/NLS/NLS/carsigns.php,v 1.1 2004/09/08 15:18:57 jan Exp $
 *
 * @package Horde_NLS
 */

$carsigns = array(
    'at' => 'A',
    'af' => 'AFG',
    'ag' => 'AG',
    'al' => 'AL',
    'ad' => 'AND',
    'ao' => 'ANG',
    'am' => 'ARM',
    'au' => 'AUS',
    'az' => 'AZ',
    'be' => 'B',
    'bd' => 'BD',
    'bb' => 'BDS',
    'bf' => 'BF',
    'bg' => 'BG',
    'bz' => 'BH',
    'bt' => 'BHT',
    'ba' => 'BIH',
    'bo' => 'BOL',
    'br' => 'BR',
    'bh' => 'BRN',
    'bn' => 'BRU',
    'bs' => 'BS',
    'bi' => 'BU',
    'vg' => 'BVI',
    'by' => 'BY',
    'bz' => 'BZ',
    'cu' => 'C',
    'cm' => 'CAM',
    'cd' => 'CD',
    'ca' => 'CDN',
    'ch' => 'CH',
    'ci' => 'CI',
    'lk' => 'CL',
    'co' => 'CO',
    'km' => 'COM',
    'cr' => 'CR',
    'cv' => 'CV',
    'cy' => 'CY',
    'cz' => 'CZ',
    'de' => 'D',
    'dj' => 'DJI',
    'dk' => 'DK',
    'do' => 'DOM',
    'kp' => 'DVRK',
    'bj' => 'DY',
    'dz' => 'DZ',
    'es' => 'E',
    'ke' => 'EAK',
    'tz' => 'EAT',
    'ug' => 'EAU',
    'ec' => 'EC',
    'er' => 'ER',
    'sv' => 'ES',
    'ee' => 'EST',
    'eg' => 'ET',
    'et' => 'ETH',
    'fr' => 'F',
    'fi' => 'FIN',
    'fj' => 'FJI',
    'li' => 'FL',
    'fo' => 'FO',
    'fm' => 'FSM',
    'ga' => 'G',
    'gb' => 'GB',
    'gi' => 'GBZ',
    'gt' => 'GCA',
    'ge' => 'GE',
    'gh' => 'GH',
    'gq' => 'GQ',
    'gr' => 'GR',
    'gy' => 'GUY',
    'hu' => 'H',
    'hk' => 'HK',
    'hn' => 'HN',
    'hr' => 'HR',
    'it' => 'I',
    'il' => 'IL',
    'in' => 'IND',
    'ir' => 'IR',
    'ie' => 'IRL',
    'iq' => 'IRQ',
    'is' => 'IS',
    'jp' => 'J',
    'jm' => 'JA',
    'jo' => 'JOR',
    'kh' => 'K',
    'ki' => 'KIR',
    'gl' => 'KN',
    'kg' => 'KS',
    'sa' => 'KSA',
    'kw' => 'KWT',
    'kz' => 'KZ',
    'lu' => 'L',
    'la' => 'LAO',
    'ly' => 'LAR',
    'lr' => 'LB',
    'ls' => 'LS',
    'lt' => 'LT',
    'lv' => 'LV',
    'mt' => 'M',
    'ma' => 'MA',
    'my' => 'MAL',
    'mc' => 'MC',
    'md' => 'MD',
    'mx' => 'MEX',
    'mn' => 'MGL',
    'mh' => 'MH',
    'mk' => 'MK',
    'mz' => 'MOC',
    'mu' => 'MS',
    'mv' => 'MV',
    'mw' => 'MW',
    'mm' => 'MYA',
    'no' => 'N',
    'an' => 'NA',
    'nl' => 'NL',
    'nz' => 'NZ',
    'om' => 'OM',
    'pt' => 'P',
    'pa' => 'PA',
    'pw' => 'PAL',
    'pe' => 'PE',
    'pk' => 'PK',
    'pl' => 'PL',
    'pg' => 'PNG',
    'cn' => 'PRC',
    'ps' => 'PS',
    'py' => 'PY',
    'qa' => 'Q',
    'ar' => 'RA',
    'bw' => 'RB',
    'tw' => 'RC',
    'cf' => 'RCA',
    'cd' => 'RCB',
    'cl' => 'RCH',
    're' => 'RE',
    'gn' => 'RG',
    'ht' => 'RH',
    'id' => 'RI',
    'mr' => 'RIM',
    'lb' => 'RL',
    'mg' => 'RM',
    'ml' => 'RMM',
    'ne' => 'RN',
    'ro' => 'RO',
    'kr' => 'ROK',
    'uy' => 'ROU',
    'ph' => 'RP',
    'sm' => 'RSM',
    'tg' => 'RT',
    'ru' => 'RUS',
    'rw' => 'RWA',
    'se' => 'S',
    'cs' => 'SCG',
    'kn' => 'SCN',
    'sz' => 'SD',
    'sg' => 'SGP',
    'sk' => 'SK',
    'si' => 'SLO',
    'sr' => 'SME',
    'sn' => 'SN',
    'sb' => 'SOL',
    'so' => 'SP',
    'st' => 'STP',
    'sd' => 'SUD',
    'sc' => 'SY',
    'sy' => 'SYR',
    'td' => 'TCH',
    'th' => 'THA',
    'tj' => 'TJ',
    'tl' => 'TL',
    'tm' => 'TM',
    'tn' => 'TN',
    'to' => 'TO',
    'tr' => 'TR',
    'tt' => 'TT',
    'tv' => 'TUV',
    'ua' => 'UA',
    'ae' => 'UAE',
    'us' => 'USA',
    'uz' => 'UZ',
    'va' => 'V',
    'vn' => 'VN',
    'vu' => 'VU',
    'GM' => 'WAG',
    'sl' => 'WAL',
    'ng' => 'WAN',
    'dm' => 'WD',
    'gd' => 'WG',
    'lc' => 'WL',
    'ws' => 'WS',
    'vc' => 'WV',
    'ye' => 'YAR',
    've' => 'YV',
    'zm' => 'Z',
    'za' => 'ZA',
    'zw' => 'ZW'
);

==> horde-3.3.11p1.tgz: horde/lib/Horde/NLS/carsigns.php <==
<?php
/**
 * The list of international license plate codes.
 *
 * $Horde: framework/NLS/NLS/carsigns.php,v 1.1 2004-09-08 15:18:57 jan Exp $
 *
 * @package Horde_NLS
 */

$carsigns = array(
    'at' => 'A',
    'af' => 'AFG',
    'ag' => 'AG',
    'al' => 'AL',
    'ad' => 'AND',
    'ao' => 'ANG',
    'am' => 'ARM',
    'au' => 'AUS',
    'az' => 'AZ',
    'be' => 'B',
    'bd' => 'BD',
    'bb' => 'BDS',
    'bf' => 'BF',
    'bg' => 'BG',
    'bz' => 'BH',
    'bt' => 'BHT',
    'ba' => 'BIH',
    'bo' => 'BOL',
    'br' => 'BR',
    'bh' => 'BRN',
    'bn' => 'BRU',
    'bs' => 'BS',
    'bi' => 'BU',
    'vg' => 'BVI',
    'by' => 'BY',
    'bz' => 'BZ',
    'cu' => 'C',
    'cm' => 'CAM',
    'cd' => 'CD',
    'ca' => 'CDN',
    'ch' => 'CH',
    'ci' => 'CI',
    'lk' => 'CL',
    'co' => 'CO',
    'km' => 'COM',
    'cr' => 'CR',
    'cv' => 'CV',
    'cy' => 'CY',
    'cz' => 'CZ',
    'de' => 'D',
    'dj' => 'DJI',
    'dk' => 'DK',
    'do' => 'DOM',
    'kp' => 'DVRK',
    'bj' => 'DY',
    'dz' => 'DZ',
    'es' => 'E',
    'ke' => 'EAK',
    'tz' => 'EAT',
    'ug' => 'EAU',
    'ec' => 'EC',
    'er' => 'ER',
    'sv' => 'ES',
    'ee' => 'EST',
    'eg' => 'ET',
    'et' => 'ETH',
    'fr' => 'F',
    'fi' => 'FIN',
    'fj' => 'FJI',
    'li' => 'FL',
    'fo' => 'FO',
    'fm' => 'FSM',
    'ga' => 'G',
    'gb' => 'GB',
    'gi' => 'GBZ',
    'gt' => 'GCA',
    'ge' => 'GE',
    'gh' => 'GH',
    'gq' => 'GQ',
    'gr' => 'GR',
    'gy' => 'GUY',
    'hu' => 'H',
    'hk' => 'HK',
    'hn' => 'HN',
    'hr' => 'HR',
    'it' => 'I',
    'il' => 'IL',
    'in' => 'IND',
    'ir' => 'IR',
    'ie' => 'IRL',
    'iq' => 'IRQ',
    'is' => 'IS',
    'jp' => 'J',
    'jm' => 'JA',
    'jo' => 'JOR',
    'kh' => 'K',
    'ki' => 'KIR',
    'gl' => 'KN',
    'kg' => 'KS',
    'sa' => 'KSA',
    'kw' => 'KWT',
    'kz' => 'KZ',
    'lu' => 'L',
    'la' => 'LAO',
    'ly' => 'LAR',
    'lr' => 'LB',
    'ls' => 'LS',
    'lt' => 'LT',
    'lv' => 'LV',
    'mt' => 'M',
    'ma' => 'MA',
    'my' => 'MAL',
    'mc' => 'MC',
    'md' => 'MD',
    'mx' => 'MEX',
    'mn' => 'MGL',
    'mh' => 'MH',
    'mk' => 'MK',
    'mz' => 'MOC',
    'mu' => 'MS',
    'mv' => 'MV',
    'mw' => 'MW',
    'mm' => 'MYA',
    'no' => 'N',
    'an' => 'NA',
    'nl' => 'NL',
    'nz' => 'NZ',
    'om' => 'OM',
    'pt' => 'P',
    'pa' => 'PA',
    'pw' => 'PAL',
    'pe' => 'PE',
    'pk' => 'PK',
    'pl' => 'PL',
    'pg' => 'PNG',
    'cn' => 'PRC',
    'ps' => 'PS',
    'py' => 'PY',
    'qa' => 'Q',
    'ar' => 'RA',
    'bw' => 'RB',
    'tw' => 'RC',
    'cf' => 'RCA',
    'cd' => 'RCB',
    'cl' => 'RCH',
    're' => 'RE',
    'gn' => 'RG',
    'ht' => 'RH',
    'id' => 'RI',
    'mr' => 'RIM',
    'lb' => 'RL',
    'mg' => 'RM',
    'ml' => 'RMM',
    'ne' => 'RN',
    'ro' => 'RO',
    'kr' => 'ROK',
    'uy' => 'ROU',
    'ph' => 'RP',
    'sm' => 'RSM',
    'tg' => 'RT',
    'ru' => 'RUS',
    'rw' => 'RWA',
    'se' => 'S',
    'cs' => 'SCG',
    'kn' => 'SCN',
    'sz' => 'SD',
    'sg' => 'SGP',
    'sk' => 'SK',
    'si' => 'SLO',
    'sr' => 'SME',
    'sn' => 'SN',
    'sb' => 'SOL',
    'so' => 'SP',
    'st' => 'STP',
    'sd' => 'SUD',
    'sc' => 'SY',
    'sy' => 'SYR',
    'td' => 'TCH',
    'th' => 'THA',
    'tj' => 'TJ',
    'tl' => 'TL',
    'tm' => 'TM',
    'tn' => 'TN',
    'to' => 'TO',
    'tr' => 'TR',
    'tt' => 'TT',
    'tv' => 'TUV',
    'ua' => 'UA',
    'ae' => 'UAE',
    'us' => 'USA',
    'uz' => 'UZ',
    'va' => 'V',
    'vn' => 'VN',
    'vu' => 'VU',
    'GM' => 'WAG',
    'sl' => 'WAL',
    'ng' => 'WAN',
    'dm' => 'WD',
    'gd' => 'WG',
    'lc' => 'WL',
    'ws' => 'WS',
    'vc' => 'WV',
    'ye' => 'YAR',
    've' => 'YV',
    'zm' => 'Z',
    'za' => 'ZA',
    'zw' => 'ZW'
);
